==> mgb-0.6.8.tar.bz2: language/lang_english_utf8/lang_import.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/
	
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ============================= //
	// lang_import.php - English 1.4 //
	// ============================= //
	//
	// This languagefile was translated by Christian Rech alias HeyJ (mail@heyj.de)
	// and edited by Jürgen Schäfer ==> juergen.schaefer(at)minetoshsoft.com
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

// header
	$lang['h_title'] = "Import of data from an older version";

// general
	$lang['next_step'] = "&raquo; Next &raquo;";
	$lang['yes'] = "Yes";
	$lang['no'] = "No";
	$lang['active'] = "Active";
	$lang['inactive'] = "Inactive";
	$lang['ok'] = "OK!";
	$lang['not_ok'] = "Failed!";

// installation
	$lang['title'] = "Import of data from an older version";

	$lang['expl_import'] = "Please provide the connection data for the database which contains the previous installation of MGB. Additionally, you have to indicate the absolute path to the old installation <b>without the domain name</b>. Example: Instead of <i>http://www.example.com/php/mgb/</i> write only <i>/php/mgb/</i>. Pay attention to the slashes at the beginning and at the end.";

// step 1
	$lang['db_title'] = "Database-details:";
	$lang['db_hostname'] = "Host:";
	$lang['db_dbname'] = "Database name:";
	$lang['db_username'] = "Username:";
	$lang['db_password'] = "Password:";
	$lang['oldgb_path'] = "Path:";
	$lang['import_settings'] = "Import settings:";

// errormessages step 1
	$lang['no_error'] = "All values are OK!";
	$lang['error_1_step1'] = "Please fill in all fields!";
	$lang['error_2_step1'] = "The connection to the database could not be established. Please check your login data!";
	$lang['error_3_step1'] = "Under the path provided, no MGB installation could be found!";
	$lang['error_4_step1'] = "The specified database is okay, but it contains no previous installation of MGB!";

// step 2
	$lang['transfer_settings'] = "transferring settings...";
	$lang['transfer_entries'] = "transferring entries...";

// finish
	$lang['import_finish'] = "Congratulations!<br><br>The data of your old MGB installation where successfully transferred to the MGB ".MGB_VERSION.". <br><br><a href='../admin/admin.php' title='Administration of the guest book'>Go to the administration</a><br><a href='../index.php' title='Visit the guest book'>Go to the guest book</a>";
?>

==> mgb-0.6.9.3.tar.bz2: language/lang_english_utf8/lang_import.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/
	
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ========================= //
	// lang_import.php - English //
	// ========================= //
	//
	// This languagefile was translated by Christian Rech alias HeyJ (mail@heyj.de)
	// and edited by Jürgen Schäfer ==> juergen.schaefer(at)minetoshsoft.com
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

// header
	$lang['h_title'] = "Import of data from an older version";

// general
	$lang['next_step'] = "&raquo; Next &raquo;";
	$lang['yes'] = "Yes";
	$lang['no'] = "No";
	$lang['active'] = "Active";
	$lang['inactive'] = "Inactive";
	$lang['ok'] = "OK!";
	$lang['not_ok'] = "Failed!";

// installation
	$lang['title'] = "Import of data from an older version";

	$lang['expl_import'] = "Please provide the connection data for the database which contains the previous installation of MGB. Additionally, you have to indicate the absolute path to the old installation <b>without the domain name</b>. Example: Instead of <i>http://www.example.com/php/mgb/</i> write only <i>/php/mgb/</i>. Pay attention to the slashes at the beginning and at the end.";

// step 1
	$lang['db_title'] = "Database-details:";
	$lang['db_hostname'] = "Host:";
	$lang['db_dbname'] = "Database name:";
	$lang['db_username'] = "Username:";
	$lang['db_password'] = "Password:";
	$lang['oldgb_path'] = "Path:";
	$lang['import_settings'] = "Import settings:";

// errormessages step 1
	$lang['no_error'] = "All values are OK!";
	$lang['error_1_step1'] = "Please fill in all fields!";
	$lang['error_2_step1'] = "The connection to the database could not be established. Please check your login data!";
	$lang['error_3_step1'] = "Under the path provided, no MGB installation could be found!";
	$lang['error_4_step1'] = "The specified database is okay, but it contains no previous installation of MGB!";

// step 2
	$lang['transfer_settings'] = "transferring settings...";
	$lang['transfer_entries'] = "transferring entries...";

// finish
	$lang['import_finish'] = "Congratulations!<br><br>The data of your old MGB installation where successfully transferred to the MGB ".MGB_VERSION.". <br><br><a href='../admin/admin.php' title='Administration of the guest book'>Go to the administration</a><br><a href='../index.php' title='Visit the guest book'>Go to the guest book</a>";
?>
